use std::time::Duration;

use super::{ResponseBody, Status};

type HeaderMap = Vec<String>;

#[derive(Debug)]
pub enum Outcome<S, E, F> {
    Success(S),
    Failure(E),
    Forward(F),
}

pub enum SameSite {
    None,
    Lax,
    Strict,
}

pub struct Cookie<'a> {
    /// Storage for the cookie string. Only used if this structure was derived
    /// from a string that was subsequently parsed.
    cookie_string: &'a str,
    name: &'a str,
    value: &'a str,
    // expires: Option<Tm>,
    max_age: Option<Duration>,
    /// The cookie's domain, if any.
    domain: Option<&'a str>,
    /// The cookie's path domain, if any.
    path: Option<&'a str>,
    /// Whether this cookie was marked Secure.
    secure: Option<bool>,
    /// Whether this cookie was marked HttpOnly.
    http_only: Option<bool>,
    /// The draft `SameSite` attribute.
    same_site: Option<SameSite>,
}

pub struct Response<'a> {
    pub headers: HeaderMap,
    pub cookies: Option<Cookie<'a>>,
    pub status: Option<Status>,
    pub body: Box<dyn ResponseBody>,
}
