use std::io::Result;

use tokio::{net::TcpStream, io::AsyncWriteExt};

use crate::handling::{methods::Method, request::Request, response::Status};

use super::Response;

impl Response<'_> {
    pub fn build(self, request: Option<Request>) -> Vec<u8> {
        let mut compiled_headers = format!("HTTP/1.1 {}\r\nContent-Length: {}\r\nContent-Type: {}\r\n", self.status.unwrap_or(Status::Ok), self.body.get_len(), self.body.get_mime())
            + &self.headers.join("\r\n")
            + "\r\n";
        let is_head = if let Some(req) = request {
            req.method == Method::Head
        } else {
            false
        };
        let compiled_body = if is_head {
            vec![]
        } else {
            self.body.get_data()
        };
        let compiled_out = unsafe { compiled_headers.as_mut_vec() };
        compiled_out.extend_from_slice(&compiled_body);
        compiled_out.to_vec()
    }
    pub async fn write(self, mut stream: TcpStream, request: Option<Request<'_>>) -> Result<()> {
        let resp = self.build(request);
        stream.write_all(&resp).await?;
        Ok(())
}}
